function [y,y_est,u,e,est_error,da_in_ratio] = sim_pp (Sys,desired_poly,init_est,init_st,k,threshold,...
                        matrix,casc,window,combination,phases)
%
%
%

% Pawel Stadnik July 26 1996
% Copyright (C) 1996 Universiteit Twente
% All Rights Reserved

%       init_est = vector theta
%       init_st = vector psi
%       all vectors of the system parameters are vertical

% init_est =  [ -a(n-1) ... -a(0) b(n-1) ... b(0) ]'(0) initial estimate
% init_st = [ y(0) ... y(n-1) u(-1) ... u(n-1) ]'(0) initial state
% Sys = [ -a(n-1) ... -a(0) b(n-1) ... b(0) ]' parameters of true system
% desired_poly = [ 1 c(n-1) ... c(0) ]


disp(blanks(5)')
disp('                           CALCULATIONS')
N = length(Sys);n = N/2;

screen=get(0,'ScreenSize');
fig=figure('MenuBar','none','NumberTitle','off','Resize','off','UserData','Figure',...
        'Position',[screen(3)/2-200 screen(4)/2-100 400 200]);axis off
handle=text(0.5,0.5,'The simulation is in progress');
set(handle,'HorizontalAlignment','center','FontSize',18,'Color',[1 1 0])
pause(1)

psi = init_st;
theta = [ init_est  zeros(N,k-1)]; % matrix  (N x k)

u = zeros(1,k)';                 % input
y = zeros(1,k)';y(1) = psi(1);   % output
e = zeros(1,k)';                 % error
y_est = zeros(1,k)';             % predicted output

est_error = zeros(1,k )';        % estimate error
est_error(1) = norm(theta(:,1)-Sys);
                % desired/actual input ratio
da_in_ratio = zeros(1,k)';da_in_ratio(1) = 1;

%        create u0 = u(1) by Ackermann's formula
[u(1),z] = ctrl_pp(theta(:,1),psi,desired_poly);
[z,h0] = ctrl_pp(Sys,psi,desired_poly);
clear z;

phi = [psi(1:n); u(1) ;psi(n+1:N-1)];

ll = fix(k/10);counter=1;
symb = '10%';

for index=2:k
   if ( index == counter*ll )
        disp(sprintf('%d %%',10*counter))
        counter = counter+1;
   end

   y_est(index) = theta(:,index-1)'*phi;
   y(index) = Sys'*phi;
   e(index) = y(index) - y_est(index);

   if ( norm(psi) <= threshold )
        theta(:,index) = theta(:,index-1);
   else
     if ( size(matrix) == [N N] )
       [theta(:,index),matrix] = ...
         est_rls(theta(:,index-1),phi,e(index),matrix);
     elseif ( size(matrix) == [1 2] )
       theta(:,index) = ...
         est_nlms(theta(:,index-1),phi,e(index),matrix(1),matrix(2));
     elseif ( size(matrix) == [1 1] )
       theta(:,index) = ...
         est_lms(theta(:,index-1),phi,e(index),matrix);
      end
   end

   est_error(index) = norm(theta(:,index)-Sys);

   if ( n == 1 )
      psi = y(index);
   else
      psi = [y(index) ; psi(1:n-1) ; u(index-1) ; psi(n+1:N-2)];
   end

   [u(index),h(:,index)] = ctrl_pp(theta(:,index),psi,desired_poly);

   da_in_ratio(index) = (h0'*psi)/u(index);

   phi = [psi(1:n); u(index); psi(n+1:N-1)];
end

clc

if ~isempty(fig)
  close(fig)
end
clear fig

plot_pp (y,y_est,u,e,est_error,da_in_ratio,Sys,theta,k,...
         casc,window,combination,phases);
if ~all(finite(y))|~all(finite(u))|~all(finite(e))| ...
   ~all(finite(da_in_ratio))|~all(finite(y_est))
   errormes('NAN')
end







